# NotYourIP

NotYourIP is a Python package that integrates various IP security APIs (such as ProxyCheck, AbuseIPDB, VirusTotal, etc.)  
to help easily detect malicious IPs and proxies.

## Installation

```bash
pip install NotYourIP
